<template>
  <van-popup
    v-model="show"
    position="bottom"
    get-container="body"
    round
    closeable
    :style="{ height: '94.6%', background: '#f3f3f3' }"
    :overlay-style="{ background: 'rgba(255,255,255,0.8)' }"
    @open="onOpen"
    @close="onClose"
  >
    <div class="header">
      <div class="title">线索上报</div>
      <div v-if="!isDetail" class="label-grid">
        <div
          class="label label-1"
          :class="[levelIndex === 1 ? 'label-1-active' : '']"
          @click="getPoliceIncidentsByLevel('Greats', 1, 1)"
        >
          <span class="label-name">特别重大</span>
          <span class="label-value">
            <span class="value">{{ data.greatsCount }}</span>
            <span class="unit">件</span>
          </span>
        </div>
        <div
          class="label label-2"
          :class="[levelIndex === 2 ? 'label-2-active' : '']"
          @click="getPoliceIncidentsByLevel('Great', 2, 1)"
        >
          <span class="label-name">重大</span>
          <span class="label-value">
            <span class="value">{{ data.greatCount }}</span>
            <span class="unit">件</span>
          </span>
        </div>
        <div
          class="label label-3"
          :class="[levelIndex === 3 ? 'label-3-active' : '']"
          @click="getPoliceIncidentsByLevel('More', 3, 1)"
        >
          <span class="label-name">较大</span>
          <span class="label-value">
            <span class="value">{{ data.moreCount }}</span>
            <span class="unit">件</span>
          </span>
        </div>
        <div
          class="label label-4"
          :class="[levelIndex === 4 ? 'label-4-active' : '']"
          @click="getPoliceIncidentsByLevel('Comon', 4, 1)"
        >
          <span class="label-name">一般</span>
          <span class="label-value">
            <span class="value">{{ data.comonCount }}</span>
            <span class="unit">件</span>
          </span>
        </div>
      </div>
      <div v-if="isDetail" class="header-back" @click="goBackList">&lt; 返回警情列表</div>
    </div>
    <div v-if="!isDetail" class="container">
      <van-loading class="loading" v-if="loading" color="#1989fa" />
      <van-empty v-if="!loading && piTotal <= 0" description="暂无数据" />
      <div class="card" v-for="(item, index) in list" :key="index">
        <div class="card-title">{{ item.name }}</div>
        <div class="card-row">
          <span class="label">报警对象：</span>
          <span class="value"> {{ item.empName }}</span>
          <span class="value"> {{ item.isPoliceContact ? "*************" : item.contact }}</span>
          <span class="link" @click.stop="item.isPoliceContact = !item.isPoliceContact">
            {{ item.isPoliceContact ? "显示" : "隐藏" }}
          </span>
        </div>
        <div class="card-row">
          <span class="label">事件类型：</span>
          <span class="value"> {{ item.policeEventType }}</span>
        </div>
        <div class="card-row">
          <span class="label">事发时间：</span>
          <span class="value"> {{ item.createdTime }}</span>
        </div>
        <div class="card-row">
          <span class="label">事发地点：</span>
          <span class="value value-ellipsis"> {{ item.address }}</span>
        </div>
        <div class="card-footer">
          <van-button class="btn" plain type="danger" @click="closeIncident(item.id)">关闭</van-button>
          <van-button class="btn" type="info" @click="lookDetail(item)">详情</van-button>
        </div>
      </div>
    </div>
    <div v-if="isDetail" class="container container-detail">
      <div class="detail-card card">
        <div class="card-row">
          <span class="label">事件标题：</span>
          <span class="value">{{ policeIncidentsData.name || "无" }}</span>
        </div>
        <div class="card-row">
          <span class="label">报警对象：</span>
          <span class="value link link-line" @click="showEmployeeByIncident(policeIncidentsData.tenantEmployeeId)">{{
            policeIncidentsData.empName || "无"
          }}</span>
        </div>
        <div class="card-row">
          <span class="label">联系方式：</span>
          <span class="value">{{ isPhone ? policeIncidentsData.contact : "***********" }}</span>
          <span class="link" @click.stop="isPhone = !isPhone">
            {{ !isPhone ? "显示" : "隐藏" }}
          </span>
        </div>
        <div class="card-row">
          <span class="label">上报时间：</span>
          <span class="value">{{ policeIncidentsData.createdTime || "无" }}</span>
        </div>
        <div class="card-row">
          <span class="label">事发地点：</span>
          <span class="value">{{ policeIncidentsData.address || "无" }}</span>
        </div>
        <div class="card-row">
          <span class="label">事件类型：</span>
          <span class="value">{{ policeIncidentsData.policeEventType || "无" }}</span>
        </div>
        <div class="card-row">
          <span class="label">事件级别：</span>
          <span class="value">{{ policeIncidentsData.policeEventLevel || "无" }}</span>
        </div>
        <div class="card-row">
          <span class="label">事件起因：</span>
          <span class="value">{{ policeIncidentsData.reason || "无" }}</span>
        </div>
        <div class="card-row">
          <span class="label">已采取措施：</span>
          <span class="value">{{ policeIncidentsData.actionTaken || "无" }}</span>
        </div>
        <div class="card-row">
          <span class="label">处理情况及发展趋势：</span>
          <span class="value">{{ policeIncidentsData.actionTendency || "无" }}</span>
        </div>
        <div class="card-row">
          <span class="label">进一步处理意见：</span>
          <span class="value">{{ policeIncidentsData.processedSuggestion || "无" }}</span>
        </div>
        <div class="card-row">
          <span class="label">现场调度指导：</span>
          <span class="value">{{ policeIncidentsData.processedLocaleGuidance || "无" }}</span>
        </div>
        <div class="card-footer">
          <van-button class="btn" plain type="danger" @click="closeIncident(policeIncidentsData.id)">关闭事件</van-button>
          <van-button class="btn" type="info" @click="railCk">周边调度</van-button>
        </div>
      </div>
    </div>
  </van-popup>
</template>

<script>
import { Popup, Loading, Empty, Button, Dialog, Notify } from "vant";
import {
  getLevelCount,
  getPoliceIncidentsNeOver,
  policeIncidentsDetail,
  policeIncidentsHandle,
} from "@/api/police-incident-controller";

export default {
  name: "policeReport",
  components: {
    [Popup.name]: Popup,
    [Loading.name]: Loading,
    [Empty.name]: Empty,
    [Button.name]: Button,
    [Notify.name]: Notify,
    [Dialog.Component.name]: Dialog.Component,
  },
  props: {
    visible: Boolean,
    tabs: Array,
    data: Object,
  },
  data() {
    return {
      show: false,
      policeIncidents: {},
      isDetail: false, //是否详情
      policeIncidentsData: {}, //警情上报详情
      isPoliceContact: true,
      piCurrentPage: 1, //当前页
      piTotal: 0, //分页总条数
      piPageSize: 9999, //分页默认3条
      levelIndex: 1,
      levelName: "",
      loading: false,
      list: [],
      isPhone: false,
    };
  },
  watch: {
    visible(value) {
      this.show = value;
    },
  },
  methods: {
    onOpen() {
      this.list = [];
      this.getPoliceIncidentsByLevel(this.tabs[0].level, 1, 1);
    },
    onClose() {
      this.$emit("update:visible", false);
    },
    /**
     * @获取警情上报数据
     * @param level
     * @param index
     * @param currentPage
     * @returns {Promise<void>}
     */
    async getPoliceIncidentsByLevel(level, index, currentPage) {
      this.isDetail = false;
      this.levelIndex = index;
      this.levelName = level;
      this.policeIncidents = {};
      this.piCurrentPage = currentPage;
      this.loading = true;
      getPoliceIncidentsNeOver({
        pageIndex: currentPage,
        pageSize: this.piPageSize,
        level: level,
        status: "None",
      })
        .then((res) => {
          console.log("PoliceIncidents", res);
          this.piTotal = res.totalCount; //总数
          this.policeIncidents = res;
          const { data } = res;
          if (data && data.length > 0) {
            this.list = data.map((x) => {
              return {
                ...x,
                isPoliceContact: true,
              };
            });
          }

          // for (let i = 0; i < this.policeIncidents.data.length; i++) {
          //   let item = this.policeIncidents.data[i];
          //   item.isPoliceContact = true;
          // }
        })
        .catch((err) => {
          console.log(err);
        })
        .finally(() => {
          this.loading = false;
        });
    },
    //关闭警情
    closeIncident(id) {
      Dialog.confirm({
        title: "提示",
        message: "是否确认关闭事件，关闭事件后则默认事件状态为已处理",
      })
        .then(() => {
          policeIncidentsHandle(id).then(() => {
            Notify({ type: "success", message: "关闭成功" });
            // 重新获取警情上报等级数量
            getLevelCount().then((res) => {
              this.$emit("update:data", res);
            });
            this.getPoliceIncidentsByLevel(this.levelName, this.levelIndex, 1);
          });
        })
        .catch(() => {
          // this.$message({
          //   type: 'info',
          //   message: '已取消关闭'
          // });
        });
    },
    // 查看详情
    lookDetail(item) {
      this.isDetail = true;
      policeIncidentsDetail(item.id).then((res) => {
        console.log(res);
        this.policeIncidentsData = res;
      });
    },
    // 返回警情列表
    goBackList() {
      this.isDetail = false;
      this.getPoliceIncidentsByLevel(this.levelName, this.levelIndex, 1);
    },
    showEmployeeByIncident(id) {
      this.$emit("update:visible", false);
      this.$emit("clickEmployee", { id });
    },
    railCk() {
      this.$emit("dispatch", this.policeIncidentsData);
    },
  },
};
</script>

<style scoped lang="less">
::v-deep .van-popup__close-icon {
  z-index: 2;
}
.header {
  width: 100%;
  height: 150px;
  position: absolute;
  top: 0;
  left: 0;
  background: url("~@/assets/images/app调度-警情上报相关图标/警情上报背景图.jpg") no-repeat;
  background-size: 100% 100%;
  z-index: 1;
  padding: 14px 12px 0 12px;
  box-sizing: border-box;
  display: flex;
  flex-direction: column;
  justify-content: space-between;
  &-back {
    font-size: 14px;
    font-family: PingFang SC-Regular, PingFang SC, serif;
    font-weight: 400;
    color: #0f71ff;
    line-height: 24px;
    margin-bottom: 22px;
  }
  .title {
    font-size: 18px;
    font-family: PingFang SC-Medium, PingFang SC, serif;
    font-weight: 500;
    color: #101741;
    line-height: 24px;
  }
  .label-grid {
    width: 100%;
    display: grid;
    grid-template-columns: repeat(4, 1fr);
    grid-gap: 16px;
    margin-top: 18px;
    .label {
      height: 58px;
      display: flex;
      flex-direction: column;
      //justify-content: space-between;
      padding: 4px 8px;
      &-1 {
        background: url("~@/assets/images/app调度-警情上报相关图标/特别重大（未选中）.png") no-repeat;
        background-size: 100% 100%;
        &-active {
          background: url("~@/assets/images/app调度-警情上报相关图标/特别重大（选中）.png") no-repeat;
          background-size: 100% 100%;
        }
      }
      &-2 {
        background: url("~@/assets/images/app调度-警情上报相关图标/重大（未选中）.png") no-repeat;
        background-size: 100% 100%;
        &-active {
          background: url("~@/assets/images/app调度-警情上报相关图标/重大（选中）.png") no-repeat;
          background-size: 100% 100%;
        }
      }
      &-3 {
        background: url("~@/assets/images/app调度-警情上报相关图标/较大（未选中）.png") no-repeat;
        background-size: 100% 100%;
        &-active {
          background: url("~@/assets/images/app调度-警情上报相关图标/较大（选中）.png") no-repeat;
          background-size: 100% 100%;
        }
      }
      &-4 {
        background: url("~@/assets/images/app调度-警情上报相关图标/一般（未选中）.png") no-repeat;
        background-size: 100% 100%;
        &-active {
          background: url("~@/assets/images/app调度-警情上报相关图标/一般（选中）.png") no-repeat;
          background-size: 100% 100%;
        }
      }
      &-name {
        font-size: 12px;
        font-family: PingFang SC-Regular, PingFang SC, serif;
        font-weight: 400;
        color: #ffffff;
        line-height: 20px;
        margin-bottom: 2px;
      }
      &-value {
        display: flex;
        flex-direction: row;
        align-items: center;
        .value {
          font-size: 20px;
          font-family: Roboto-Medium, Roboto, serif;
          font-weight: 500;
          color: #ffffff;
          line-height: 22px;
        }
        .unit {
          font-size: 12px;
          font-family: PingFang SC-Regular, PingFang SC, serif;
          font-weight: 400;
          color: #ffffff;
          line-height: 20px;
          margin-left: 2px;
        }
      }
    }
  }
}
.container {
  width: 100%;
  height: calc(100% - 150px);
  overflow-y: auto;
  overflow-x: hidden;
  //background: #f3f3f3;
  position: absolute;
  bottom: 0;
  left: 0;
  padding: 8px 12px;
  box-sizing: border-box;
  .card {
    width: 100%;
    // height: 184px;
    background: #ffffff;
    box-shadow: 0px 2px 12px 0px rgba(0, 0, 0, 0.04);
    border-radius: 6px;
    margin-bottom: 8px;
    padding: 12px;
    &:last-child {
      margin-bottom: 0;
    }
    &-title {
      font-size: 14px;
      font-family: PingFang SC-Medium, PingFang SC, serif;
      font-weight: 500;
      color: #303133;
      line-height: 22px;
      margin-bottom: 4px;
    }
    &-row {
      display: flex;
      margin-bottom: 2px;
      .label {
        font-size: 12px;
        font-family: PingFang SC-Regular, PingFang SC, serif;
        font-weight: 400;
        color: #909399;
        line-height: 22px;
      }
      .value {
        font-size: 12px;
        font-family: PingFang SC-Regular, PingFang SC, serif;
        font-weight: 400;
        color: #303133;
        line-height: 22px;
        &:nth-child(3) {
          margin-left: 12px;
        }
        &-ellipsis {
          width: 258px;
          overflow: hidden;
          text-overflow: ellipsis;
          white-space: nowrap;
        }
      }
      .link {
        font-size: 12px;
        font-family: PingFang SC-Regular, PingFang SC, serif;
        font-weight: 400;
        color: #0f71ff;
        line-height: 22px;
        &-line {
          text-decoration: underline;
        }
      }
    }
    &-footer {
      width: 100%;
      margin-top: 12px;
      height: 28px;
      display: flex;
      flex-direction: row;
      justify-content: flex-end;
      .btn {
        min-width: 80px;
        height: 28px;
        margin-left: 10px;
        border-radius: 6px 6px 6px 6px;
        font-size: 12px;
        font-family: PingFang SC-Regular, PingFang SC, serif;
        font-weight: 400;
        line-height: 20px;
      }
    }
  }
  .loading {
    position: absolute;
    left: 50%;
    top: 50%;
    transform: translate(-50%, -50%);
  }
  .detail-card {
    width: 100%;
    height: 446px;
    background: #ffffff;
    box-shadow: 0 2px 12px 0 rgba(0, 0, 0, 0.04);
    border-radius: 6px 6px 6px 6px;
    padding: 12px;
    box-sizing: border-box;
  }
  &-detail {
    //height: calc(100% - 150px + 24px);
    bottom: 24px;
    z-index: 2;
    .card {
      &-row {
        margin-bottom: 10px;
      }
    }
  }
}
</style>
